# Python Waldur Client

Python API client for [backend](https://github.com/waldur/waldur-mastermind) of [Waldur project](https://waldur.com/).

## Contributing

Install `pre-commit`

```bash
pip install pre-commit
pre-commit install
```
